# Notifications Center
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/notifications-center#overview)
  * [Notification Channels](https://help.sap.com/docs/leanix/ea/notifications-center#notification-channels)
  * [Audit Log](https://help.sap.com/docs/leanix/ea/notifications-center#audit-log)
  * [Disabling All Notifications for Your Organization](https://help.sap.com/docs/leanix/ea/notifications-center#disabling-all-notifications-for-your-organization)


Configure notification settings for your workspace.
